/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "controllers/dif/common/commandline/DiffCmdDef.h"
#include "Utilities/StringUtilities.h"
#include <iostream>

#include "CyclopsParser.h"
#include "CyclopsFileCmd.h"
#include "CyclopsParCmd.h"

using namespace std;
using namespace boost;

namespace cyclops {

const std::string CyclopsParser::TYPE = "cyclops";

CyclopsParser::CyclopsParser() : DiffParser() {
}

CyclopsParser::~CyclopsParser() {
}

bool CyclopsParser::decode(Items items) throw (CommonCmdDef::BadInput) {
	bool found = true;

	try {
		if (items.end()) {
			throw CommonCmdDef::BadInput();
		}

		if (!(*items).empty()) {
			if (AbstractParser::decode(items)) {
				// Already done
			} else if (StringUtilities::cmp(*items, "file", 4) == true) {
				// File command
				CyclopsFileCmd cmd(this);
				cmd.parse(items);
			} else if (StringUtilities::cmp(*items, "par", 3) == true) {
				// Par command
				CyclopsParCmd cmd(this);
				cmd.parse(items);
			}
			else {
				found = DiffParser::decode(items);
			}
		} else {
			found = false;
		}
	} catch (CannotSetValue& e) {
		// Print Error
		CommandLineManager::getInstance()->outputError(COMMAND_REFUSED_ERROR, "");
	} catch (CommonCmdDef::BadInput& e) {
		// Print Error
		if (e.noerrormsg == false) {
			CommandLineManager::getInstance()->outputError(COMMAND_LINE_ILLEGAL_PARAM, ": " + e.m_Input);
		}
	} catch (...) {
		// Print Error
		CommandLineManager::getInstance()->outputError(COMMAND_LINE_ILLEGAL_PARAM, "Unknown error");
	}
	return found;
}

}
