/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef CAENQDCCONTROLLER_H
#define CAENQDCCONTROLLER_H

#include "CAENAdcController.h"
#include "drivers/caen/caen_qdc/CAENQdcDriver.h"

namespace npp {

/*!
 * \class CAENV1724Driver
 * \brief Main class for the CAENV1724Driver device driver
 *
 * \par
 * Class for CAENV1724Driver driver. Implements DeviceDriver methods.
 * \par
 * The CAENV1724Driver device manages the global functionality of the CAEN V1724 VME Digitiser.
 */


class CAENQdcController: public CAENAdcController {

public:

	//! Driver type value
	static const std::string TYPE;

	/*!
	 * \brief Constructor
	 * \param[in] name the name of the device driver
	 */
	CAENQdcController(const std::string& name);

	/*!
	 * \brief Destructor
	 */
	virtual ~CAENQdcController();

	/**
	 * \brief Postconfiguration
	 */
	virtual void postConfiguration();

    // Board properties
    Property<int32> groupChannel;
    Property<int32> groupChannels;
    Property<int32> chargeSensitivity;
    Property<int32> inputSmoothing;
    Property<int32> baselineMean;

    // Group properties
    Property<int32>displayGroup;
    Property<float64>triggerHoldOff;
    Property<float64>gateWidth;
    Property<float64>preGate;
    DynamicProperty<int32> channelActive;
    DynamicProperty<int32> triggerThreshold;

protected:

	DriverPtr<caen_qdc::CAENQdcDriver> m_dgtzDriver;

private:

    void initBoard();

	void refreshDisplayGroupProperty(int32 aValue) throw (CannotSetValue);
	void refreshGroupChannelProperty(int32 aValue) throw (CannotSetValue);
	void refreshDppAcqModeProperty(int32 aValue) throw (CannotSetValue);
	void refreshPulsePolarityProperty(int32 aValue) throw (CannotSetValue);
	void refreshChannelActiveProperty(int32 aValue) throw (CannotSetValue);
	void refreshRecordLengthProperty(int32 aValue) throw (CannotSetValue);
	void refreshTriggerHoldOffProperty(float64 aValue) throw (CannotSetValue);
	void refreshChargeSensitivityProperty(int32 aValue) throw (CannotSetValue);
	void refreshGateWidthProperty(float64 aValue) throw (CannotSetValue);
	void refreshPreGateProperty(float64 aValue) throw (CannotSetValue);
	void refreshBaselineMean(int32 aValue) throw (CannotSetValue);
	void refreshDcOffsetProperty(int32 aValue) throw (CannotSetValue);
	void refreshPreTriggerProperty(int32 aValue) throw (CannotSetValue);
	void refreshActivateChannelProperty(int32 index, int32 aValue) throw (CannotSetValue);
	void refreshTriggerThresholdProperty(int32 index, int32 aValue) throw (CannotSetValue);

	void updateBoardProperties();

	virtual void clearData();
	virtual void writeParam();
	virtual void refreshNbChannelsProperty(int32 aGroup) throw (CannotSetValue) ;
	virtual void refreshDisplayChannelProperty(int32 aGroup) throw (CannotSetValue) ;
	virtual void initChannel(int32 aGroup);
};

}
#endif //CAENQDCCONTROLLER_H
