/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://joinup.ec.europa.eu/software/page/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#ifndef PHOTONICSSTATE_H
#define PHOTONICSSTATE_H

#include <Driver.h>
#include "drivers/gigecam/photonics/PhotonicsDriver.h"



namespace photonics {

/*!
 * \class PhotonicsState
 * \brief Virtual class for implement State pattern
 *
 * Define all methods that perfect, simulated and real classes have to implement
 */
class PhotonicsState: public DriverState<PhotonicsDriver> {

public:

	/*!
	 * \brief Constructor
	 * \param[in] owner The device driver main class link
	 */
	PhotonicsState(PhotonicsDriver* owner) :
			DriverState<PhotonicsDriver>(owner) {
	}
	/*!
	 * \brief Destructor
	 */
	virtual ~PhotonicsState() {
	}

	/*!
	 * \brief Clear command implementation
	 */
	virtual void clear() = 0;

	/*!
	 * \brief Write Param command implementation
	 */
	virtual void writeParam() = 0;

	/*!
	 * \brief Read command implementation
	 */
	virtual void read() = 0;

	/*!
	 * \brief Synchronize Read command implementation
	 */
	virtual void synchroniseRead() = 0;

	/*!
	 * \brief Start command implementation
	 */
	virtual void start() = 0;

	/*!
	 * \brief Resume command implementation
	 */
	virtual void resume() = 0;

	/*!
	 * \brief Pause command implementation
	 */
	virtual void pause() = 0;

	/*!
	 * \brief Stop command implementation
	 */
	virtual void stop() = 0;

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readStatus() = 0;

	/*!
	 * \brief Read Infos command implementation
	 */
	virtual void readInfos() = 0;
//
//	/*!
//	 * \brief Regroup command implementation
//	 */
//	virtual void regroup() = 0;

};

}
#endif //PHOTONICSSTATE_H
